vecto
*****

.. image:: https://api.travis-ci.org/vecto-ai/vecto.svg?branch=master
    :target: https://travis-ci.org/vecto-ai/vecto
    :alt: build status from Travis CI

.. image:: https://ci.appveyor.com/api/projects/status/github/vecto-ai/vecto?branch=master&svg=true
    :target: https://ci.appveyor.com/project/vecto-ai/vecto
    :alt: build status from AppVeyor

.. image:: https://coveralls.io/repos/github/vecto-ai/vecto/badge.svg?branch=master
    :target: https://coveralls.io/github/vecto-ai/vecto?branch=master
    :alt: coveralls badge

.. image:: https://badge.fury.io/py/vecto.svg
    :target: https://badge.fury.io/py/vecto
    :alt: pypi version

.. image:: https://badges.gitter.im/badge.svg
   :alt: Join the chat at https://gitter.im/vecto-ai/Lobby
   :target: https://gitter.im/vecto-ai/Lobby

vecto helps to perform a range of tasks within a framework of vector space models of computational linguistics.

What functionality is included
==============================

* creating word embeddings by counting and neural-based methods, including sub-word-level models
* importing and exporting from a banch of popular formats of word embeddings and providing unified access to word-vectors
* perfroming a range of downstream tasks / benchmarks on embeddings
* visualising embeddings

How do I get set up?
====================

* ``pip3 install vecto`` for stable version
* ``pip3 install git+https://github.com/vecto-ai/vecto.git`` for latest dev version
* Python 3.5 or later is required

📖 Documentation
================

=================== ===
`Tutorial`_         vecto overview and end-to-end examples.
`API Reference`_    The detailed reference for vecto API.
`Contribute`_       How to contribute to the vecto project and code base.
=================== ===

.. _Tutorial: http://vecto.readthedocs.io/en/docs/tutorial/index.html
.. _API Reference: http://vecto.readthedocs.io/en/docs/reference/index.html
.. _Contribute: http://vecto.readthedocs.io/en/docs/contribution.html
